import momentumx as mx
import threading
import signal

STREAM = "mx://incrementer"

cancel = threading.Event()
signal.signal(signal.SIGINT, (lambda _sig, _frm: cancel.set()))

stream = mx.Consumer(STREAM, cancel)

while stream.is_alive:
    string = stream.receive_string()
    if string:
        print("Received:", string)
    else:
        if cancel.wait(0.5):
            break
        print("Waiting for data")



import threading
import time

from momentumx import Producer, Consumer


def emitter(cancel: threading.Event):
    stream = Producer("emitter", 8, 4, True, cancel)
    while stream.subscriber_count == 0:
        print("waiting for subscriber(s)")
        if cancel.wait(0.5):
            print("emitter canceled before starting")
            return

    i = 0
    while i <= 60 and not cancel.is_set():
        if stream.send_string(str(i)):
            i += 1
            time.sleep(0.25)
    cancel.set()


def doubler(cancel: threading.Event):
    time.sleep(1)
    istream = Consumer("emitter", cancel)
    ostream = Producer("doubler", 8, 4, True, cancel)

    while ostream.subscriber_count == 0:
        print("waiting for subscriber(s)")
        if cancel.wait(0.5):
            print("doubler canceled before starting")
            return

    while istream.is_alive and not cancel.is_set():
        sval = istream.receive_string()
        if sval:
            ival = int(sval.strip())
            assert ostream.send_string(str(ival * 2))


def printer(cancel: threading.Event):
    time.sleep(2)
    stream = Consumer("doubler", cancel)
    while stream.is_alive and not cancel.is_set():
        val = stream.receive_string()
        if val:
            print(val)


cancel = threading.Event()
t1 = threading.Thread(target=emitter, args=(cancel,))
t2 = threading.Thread(target=doubler, args=(cancel,))
t3 = threading.Thread(target=printer, args=(cancel,))

t1.start()
t2.start()
t3.start()

try:
    while not cancel.wait(0.5):
        pass
except KeyboardInterrupt:
    print("received ctrl-c")
finally:
    cancel.set()
    t1.join()
    t2.join()
    t3.join()



from setuptools import find_packages
from skbuild import setup

__version__ = "2.2.2"

from pathlib import Path
long_description = (Path(__file__).parent / "README.md").read_text()

setup(
    name="MomentumX",
    version=__version__,
    description="Zero-copy shared memory IPC library for building complex streaming data pipelines capable of processing large datasets",
    long_description=long_description,
    long_description_content_type='text/markdown',   
    author="Captivation Software, LLC",
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    cmake_install_dir="src/momentumx",
    extras_require={"test": ["pytest", "numpy"]},
    python_requires=">=3.6",
    url="https://github.com/captivationsoftware/MomentumX",
    keywords=["shm", "shared memory", "zero-copy", "numpy", "big data", "scipy", "pubsub", "pipeline"]
)



import threading
import time

import momentumx as mx

STREAM = "mx://threaded"


def consumer(cancel: threading.Event):
    time.sleep(1)
    stream = mx.Consumer(STREAM, cancel)

    while stream.is_alive and not cancel.is_set():
        string = stream.receive_string()
        if string:
            print("Received:", string)
    cancel.set()


def producer(cancel: threading.Event):
    stream = mx.Producer(STREAM, 100, 10, True, cancel)
    i = 0
    while i < 1000 and not cancel.is_set():
        if stream.send_string(str(i)):
            print("Sent: ", i)
            i += 1
    
    time.sleep(1)


cancel = threading.Event()
t1 = threading.Thread(target=consumer, args=(cancel,))
t2 = threading.Thread(target=producer, args=(cancel,))

t1.start()
t2.start()

try:
    while not cancel.wait(0.5):
        pass
except KeyboardInterrupt:
    print("received ctrl-c")
finally:
    cancel.set()
    t1.join()
    t2.join()
